package sun.security.x509;

import sun.security.util.DerOutputStream;
import sun.security.util.DerValue;
import java.io.IOException;
import sun.security.util.DerInputStream;
import sun.security.util.BitArray;

public class UniqueIdentity
{
    private BitArray id;
    
    public UniqueIdentity(BitArray id) {
        this.id = id;
    }
    
    public UniqueIdentity(byte[] a) {
        this.id = new BitArray(a.length * 8, a);
    }
    
    public UniqueIdentity(DerInputStream derInputStream) throws IOException {
        this.id = derInputStream.getDerValue().getUnalignedBitString(true);
    }
    
    public UniqueIdentity(DerValue derValue) throws IOException {
        this.id = derValue.getUnalignedBitString(true);
    }
    
    @Override
    public String toString() {
        return "UniqueIdentity:" + this.id.toString() + "\n";
    }
    
    public void encode(DerOutputStream derOutputStream, byte b) throws IOException {
        byte[] byteArray = this.id.toByteArray();
        int b2 = byteArray.length * 8 - this.id.length();
        derOutputStream.write((int)b);
        derOutputStream.putLength(byteArray.length + 1);
        derOutputStream.write(b2);
        derOutputStream.write(byteArray);
    }
    
    public boolean[] getId() {
        if (this.id == null) {
            return null;
        }
        return this.id.toBooleanArray();
    }
}
